unicore.hub.client
==================

Client library to interact with Universal Core's `unicore.hub`

.. image:: https://travis-ci.org/universalcore/unicore.hub.client.svg?branch=develop
    :target: https://travis-ci.org/universalcore/unicore.hub.client
    :alt: Continuous Integration

.. image:: https://coveralls.io/repos/universalcore/unicore.hub.client/badge.png?branch=develop
    :target: https://coveralls.io/r/universalcore/unicore.hub.client?branch=develop
    :alt: Code Coverage

.. image:: https://pypip.in/version/unicore.hub.client/badge.svg
    :target: https://pypi.python.org/pypi/unicore.hub.client
    :alt: Pypi Package
